==> nmh-0.03.tar.gz: nmh-0.03/acconfig.h <==

/****** BEGIN USER CONFIGURATION SECTION *****/

/*
 * You need to define the OS specific defines in the relevant
 * section.  These are being slowly removed, and converted to
 * auto-config, but for right now, this is needed.
 */

/*
 * Solaris 2.x
 */
#define SYS5  1
#define SVR4  1

/*
 * SunOS 4.1.x
 */
/* #define BIND   1 */
/* #define BSD42  1 */
/* #define BSD43  1 */
/* #define SUN40  1 */

/*
 * Irix
 */
/* define SYS5  1 */
/* define SVR4  1 */

/*
 * Linux
 */
/* nmh IS CURRENTLY BROKEN ON LINUX */

/*
 * FreeBSD 2.x, NetBSD 1.x, OpenBSD 2.x
 */
/* #define BIND   1 */
/* #define BSD42  1 */
/* #define BSD43  1 */
/* #define BSD44  1 */

/*
 * Define to 1 the type of file locking to use?
 * Currently you can only use one type.
 */
#define FCNTL 1
/* #define LOCKF 1 */
/* #define FLOCK 1 */

/*
 * Define this if your passwords are stored in some type of
 * distributed name service, such as NIS, or NIS+.
 */
#define DBMPWD  1

/*
 * If this is defined, the repl command will have the
 * default of '-nocc all', else it will default to '-cc all'.
 */
#define ATHENA  1

/*
 * Directs nmh not to try and rewrite addresses
 * to their official form.
 */
#define DUMB    1

/*
 * Directs inc to note "From " lines as Return Path:
 * info.
 */
#define RPATHS  1

/*
 * If this is defined, nmh will recognize the ~ construct.
 */
#define MHRC    1

/*
 * Use sendmail as transport agent.  Currently, this is
 * the only transport agent that nmh works correctly with.
 */
#define SENDMTS 1

/*
 * Compile in support for MIME.
 */
#define MIME    1

/*
 * If you enable POP support, this is the the port name
 * that nmh will use.  Make sure this is defined in your
 * /etc/services file (or its NIS/NIS+ eqivalent).
 */
#define POPSERVICE "pop3"

/*
 * Define the default creation modes for folders and messages.
 */
#define DEFAULT_FOLDER_MODE "0711"
#define DEFAULT_MESSAGE_MODE "0644"

/*
 * The prefix to use when messages are "removed" by rmm.
 */
#define BACKUP_PREFIX ","

/*
 * Name of link to file to which you are replying.
 */
#define LINK "@"

/*
 * Enables slocal to detect and surpress duplicate
 * messages recieved.  Don't use this until I think
 * some more about the locking code.
 */
/* #define MSGID   1 */

/*
 * If wait/waitpid returns an int (no union wait).
 */
#define WAITINT 1

/*
 * Define if you have socket support.  I'm assuming
 * everyone has this these days.
 */
#define SOCKETS 1

/***** END USER CONFIGURATION SECTION *****/
@TOP@

/*
 * Define this if you want SMTP (simple mail transport protocol)
 * support.  When sending mail, instead of passing the message to
 * the mail transport agent (typically sendmail), nmh will open a
 * socket connection to the mail port on the machine specified in
 * the `mts.conf' file (default is localhost), and speak SMTP directly.
 * This requires support for sockets, of course.
 */
#undef SMTP

/*
 * Define this to compile client-side support for pop into
 * inc and msgchk.  Do not change this value manually.  You
 * must run configure with the '--enable-nmh-pop' option
 * to correctly build the pop client support.
 */
#undef POP

/*
 * Compile in support for the Emacs front-end mh-e.
 */
#undef MHE

/* Define to 1 if your termcap library has the ospeed variable */
#undef HAVE_OSPEED
/* Define to 1 if you have ospeed, but it is not defined in termcap.h */
#undef MUST_DEFINE_OSPEED

/* Define to 1 if tgetent() accepts NULL as a buffer */
#undef TGETENT_ACCEPTS_NULL

/* Define to 1 if you use POSIX style signal handling */
#undef POSIX_SIGNALS
 
/* Define to 1 if you use BSD style signal handling (and can block signals) */
#undef BSD_SIGNALS
 
/* Define to 1 if you use SYS style signal handling (and can block signals) */
#undef SYSV_SIGNALS
 
/* Define to 1 if you have no signal blocking at all (bummer) */
#undef NO_SIGNAL_BLOCKING

/* Define to `unsigned int' if <sys/types.h> or <signal.h> doesn't define */
#undef sigset_t

/*
 * Define to 1 if your vi has ATT bug, such that it returns
 * non-zero exit codes on `pseudo-errors'.
 */
#undef ATTVIBUG

/* Define ruserpass as _ruserpass if your libraries have a bug *
 * such that it can't find ruserpass, but can find _ruserpass. */
#undef ruserpass

/* Define if your system defines TIOCGWINSZ in sys/ioctl.h.  */
#undef GWINSZ_IN_SYS_IOCTL

/* Define if your system defines `struct winsize' in sys/ptem.h.  */
#undef WINSIZE_IN_PTEM

==> nmh-0.04.tar.gz: nmh-0.04/acconfig.h <==

/****** BEGIN USER CONFIGURATION SECTION *****/

/*
 * You need to define the OS specific defines in the relevant
 * section.  These are being slowly removed, and converted to
 * auto-config, but for right now, this is needed.
 */

/*
 * Solaris 2.x
 */
#define SYS5  1
#define SVR4  1

/*
 * SunOS 4.1.x
 */
/* #define BIND     1 */
/* #define BSD42    1 */
/* #define BSD43    1 */
/* #define SUN40    1 */
/* #define ZONEINFO 1 */

/*
 * Irix
 */
/* define SYS5  1 */
/* define SVR4  1 */

/*
 * Linux
 */
/* nmh IS CURRENTLY BROKEN ON LINUX */

/*
 * FreeBSD 2.x, NetBSD 1.x, OpenBSD 2.x
 */
/* #define BIND     1 */
/* #define BSD42    1 */
/* #define BSD43    1 */
/* #define BSD44    1 */
/* #define ZONEINFO 1 */

/*
 * Define to 1 the type of file locking to use.  You need to
 * make sure the type of locking you use is compatible with
 * other programs which may modify your maildrops.
 * Currently you can only use one type.
 */
#define FCNTL 1
/* #define LOCKF 1 */
/* #define FLOCK 1 */

/*
 * Define this if your passwords are stored in some type of
 * distributed name service, such as NIS, or NIS+.
 */
#define DBMPWD  1

/*
 * If this is defined, the repl command will have the
 * default of '-nocc all', else it will default to '-cc all'.
 */
#define ATHENA  1

/*
 * Directs nmh not to try and rewrite addresses
 * to their official form.  You probably don't
 * want to change this without good reason.
 */
#define DUMB    1

/*
 * Directs inc to note "From " lines as Return Path:
 * info.
 */
#define RPATHS  1

/*
 * If this is defined, nmh will recognize the ~ construct.
 */
#define MHRC    1

/*
 * Use sendmail as transport agent.  Currently, this is
 * the only transport agent that nmh works correctly with.
 */
#define SENDMTS 1

/*
 * Compile in support for MIME.
 */
#define MIME    1

/*
 * If you enable POP support, this is the the port name
 * that nmh will use.  Make sure this is defined in your
 * /etc/services file (or its NIS/NIS+ eqivalent).
 */
#define POPSERVICE "pop3"

/*
 * Define the default creation modes for folders and messages.
 */
#define DEFAULT_FOLDER_MODE "0711"
#define DEFAULT_MESSAGE_MODE "0644"

/*
 * The prefix to use when messages are "removed" by rmm.
 */
#define BACKUP_PREFIX ","

/*
 * Name of link to file to which you are replying.
 */
#define LINK "@"

/*
 * If wait/waitpid returns an int (no union wait).
 */
#define WAITINT 1

/*
 * Define if you have socket support.  I'm assuming
 * everyone has this these days.
 */
#define SOCKETS 1

/***** END USER CONFIGURATION SECTION *****/
@TOP@

/*
 * Define this if you want SMTP (simple mail transport protocol)
 * support.  When sending mail, instead of passing the message to
 * the mail transport agent (typically sendmail), nmh will open a
 * socket connection to the mail port on the machine specified in
 * the `mts.conf' file (default is localhost), and speak SMTP directly.
 * This requires support for sockets, of course.
 */
#undef SMTP

/*
 * Define this to compile client-side support for pop into
 * inc and msgchk.  Do not change this value manually.  You
 * must run configure with the '--enable-nmh-pop' option
 * to correctly build the pop client support.
 */
#undef POP

/*
 * Compile in support for the Emacs front-end mh-e.
 */
#undef MHE

/* Define to 1 if your termcap library has the ospeed variable */
#undef HAVE_OSPEED
/* Define to 1 if you have ospeed, but it is not defined in termcap.h */
#undef MUST_DEFINE_OSPEED

/* Define to 1 if tgetent() accepts NULL as a buffer */
#undef TGETENT_ACCEPTS_NULL

/* Define to 1 if you use POSIX style signal handling */
#undef POSIX_SIGNALS
 
/* Define to 1 if you use BSD style signal handling (and can block signals) */
#undef BSD_SIGNALS
 
/* Define to 1 if you use SYS style signal handling (and can block signals) */
#undef SYSV_SIGNALS
 
/* Define to 1 if you have no signal blocking at all (bummer) */
#undef NO_SIGNAL_BLOCKING

/* Define to `unsigned int' if <sys/types.h> or <signal.h> doesn't define */
#undef sigset_t

/*
 * Define to 1 if your vi has ATT bug, such that it returns
 * non-zero exit codes on `pseudo-errors'.
 */
#undef ATTVIBUG

/* Define ruserpass as _ruserpass if your libraries have a bug *
 * such that it can't find ruserpass, but can find _ruserpass. */
#undef ruserpass

/* Define if your system defines TIOCGWINSZ in sys/ioctl.h.  */
#undef GWINSZ_IN_SYS_IOCTL

/* Define if your system defines `struct winsize' in sys/ptem.h.  */
#undef WINSIZE_IN_PTEM
